@@ -2,12 +2,14 @@
 # flake8: noqa
 """Python tools for stock analysis"""
 from .extensions.drawdown import Drawdown
-from .extensions.wealthindex import WealthIndex
+from .extensions.drawdown_durations import DrawdownDurations
+from .extensions.cwi import CumulativeWealthIndex
 from .extensions.monthly_returns import MonthlyReturns
 from .extensions.annual_returns import AnnualReturns
 from .extensions.weekly_returns import WeeklyReturns
 from .extensions.prices import Prices
 from .extensions.returns import Returns
+from .extensions.log_returns import LogReturns
 from .extensions.srri import SRRI
 
 from .utilities.rolling_returns import RollingReturns
@@ -21,16 +23,18 @@ from .utilities.beta_covariance import BetaCovariance
 from .utilities.beta_regression import BetaRegression
 
 
-__version__ = "1.4.1"
+__version__ = "3.0.1"
 __all__ = [
     "Drawdown",
-    "WealthIndex",
+    "DrawdownDurations",
+    "CumulativeWealthIndex",
     "Prices",
     "SRRI",
     "MonthlyReturns",
     "WeeklyReturns",
     "AnnualReturns",
     "Returns",
+    "LogReturns",
     "RollingReturns",
     "RollingVolatility",
     "BetaCovariance",
