@@ -1,10 +1,12 @@
 import pandas as pd
 import matplotlib.pyplot as plt
+from pandas.api.extensions import register_series_accessor, register_dataframe_accessor
 
 
-@pd.api.extensions.register_series_accessor("prices")
+@register_series_accessor("prices")
+@register_dataframe_accessor("prices")
 class Prices:
-    """Given a Prices Series, will attach useful attributes"""
+    """Given a pandas object, will attach useful attributes"""
 
     def __init__(self, pandas_obj):
         self._validate(pandas_obj)
@@ -12,32 +14,24 @@ class Prices:
 
     @staticmethod
     def _validate(obj):
-        assert isinstance(obj, pd.Series)
         assert isinstance(obj.index, pd.DatetimeIndex)
 
     @property
     def data(self):
         return self._obj
 
-    @property
-    def returns(self):
-        return self._obj.returns
+    def __call__(self):
+        return self._obj
+
+    def __getitem__(self, idx):
+        return self._obj.loc[idx]
 
     @property
-    def log_returns(self):
-        return self._obj.log_returns
-
-    @property
-    def weekly_returns(self):
-        return self._obj.weekly_returns
-
-    @property
-    def monthly_returns(self):
-        return self._obj.monthly_returns
-
-    @property
-    def annual_returns(self):
-        return self._obj.annual_returns
+    def cumulative_return(self):
+        """Returns the cumulative return on an investment.
+        It is the aggregate amount that the investment has gained
+        or lost over time, independent of the amount of time involved."""
+        return (self._obj.iloc[-1] - self._obj.iloc[0]) / self._obj.iloc[0]
 
     def plot(self, ax=None, **kwargs):  # pragma: no cover
         if ax is None:
