@@ -21,7 +21,7 @@ class RollingRealizedVolatility:
     if monthly returns then window = 12 for annualization
     """
 
-    def __init__(self, pandas_obj: pd.Series, rolling_window: int, window: int = 252):
+    def __init__(self, pandas_obj, rolling_window: int, window: int = 252):
         self._validate(pandas_obj, rolling_window, window)
         self.rolling_window = rolling_window
         factor = window / rolling_window
@@ -31,7 +31,7 @@ class RollingRealizedVolatility:
         )
 
     @staticmethod
-    def _validate(obj: pd.Series, rolling_window: int, window: int):
+    def _validate(obj, rolling_window: int, window: int):
         assert isinstance(obj.index, pd.DatetimeIndex)
         assert rolling_window > 0 and isinstance(
             rolling_window, int
@@ -41,7 +41,7 @@ class RollingRealizedVolatility:
         ), "rolling_window must be possitive integer"
 
     @property
-    def data(self) -> pd.Series:
+    def data(self):
         return self._obj
 
     def plot(self, ax=None, **kwargs):  # pragma: no cover
